@@ -5,7 +5,12 @@ Not intended to be used outside compas* packages.
 """
 import os
 import sys
-import subprocess
+
+try:
+    NotADirectoryError
+except NameError:
+    class NotADirectoryError(Exception):
+        pass
 
 PY3 = sys.version_info[0] == 3
 system = sys.platform
@@ -14,6 +19,16 @@ system = sys.platform
 if 'ironpython' in sys.version.lower() and os.name == 'nt':
     system = 'win32'
 
+try:
+    from compas_bootstrapper import PYTHON_DIRECTORY
+except:
+    # We re-map CONDA_PREFIX for backwards compatibility reasons
+    # In a few releases down the line, we can get rid of this bit
+    try:
+        from compas_bootstrapper import CONDA_PREFIX as PYTHON_DIRECTORY
+    except:
+        PYTHON_DIRECTORY = None
+
 
 def select_python(python_executable):
     """Selects the most likely python interpreter to run.
@@ -29,16 +44,6 @@ def select_python(python_executable):
     """
     python_executable = python_executable or 'pythonw'
 
-    try:
-        from compas_bootstrapper import PYTHON_DIRECTORY
-    except:
-        # We re-map CONDA_PREFIX for backwards compatibility reasons
-        # In a few releases down the line, we can get rid of this bit
-        try:
-            from compas_bootstrapper import CONDA_PREFIX as PYTHON_DIRECTORY
-        except:
-            PYTHON_DIRECTORY = None
-
     if PYTHON_DIRECTORY and os.path.exists(PYTHON_DIRECTORY):
         python = os.path.join(PYTHON_DIRECTORY, python_executable)
         if os.path.exists(python):
@@ -63,6 +68,26 @@ def select_python(python_executable):
     return python_executable
 
 
+def prepare_environment():
+    """Prepares an environment context to run Python on.
+
+    If Python is being used from a conda environment, this is roughly equivalent
+    to activating the conda environment by setting up the correct environment
+    variables.
+    """
+    env = os.environ.copy()
+
+    if PYTHON_DIRECTORY:
+        lib_bin = os.path.join(PYTHON_DIRECTORY, 'Library', 'bin')
+        if os.path.exists(lib_bin):
+            env['PATH'] += os.pathsep + lib_bin
+
+        lib_bin = os.path.join(PYTHON_DIRECTORY, 'lib')
+        if os.path.exists(lib_bin):
+            env['PATH'] += os.pathsep + lib_bin
+
+    return env
+
 def absjoin(*parts):
     return os.path.abspath(os.path.join(*parts))
 
@@ -72,6 +97,7 @@ _os_symlink = None
 
 
 def create_symlink_polyfill():
+    import subprocess
     def symlink_ms(source, link_name):
         subprocess.check_output(
             ['mklink', '/D', link_name, source], stderr=subprocess.STDOUT, shell=True)
