@@ -22,15 +22,14 @@ from functools import partial
 import compas
 
 from compas.datastructures import Mesh
+from compas.datastructures import mesh_flip_cycles
+from compas.datastructures import mesh_subdivide
 
 from compas.geometry import centroid_points
 from compas.utilities import hex_to_rgb
 from compas.utilities import flatten
 from compas.utilities import pairwise
 
-from compas.topology import mesh_flip_cycles
-from compas.topology import mesh_subdivide
-
 from compas.viewers.core import Camera
 from compas.viewers.core import Mouse
 from compas.viewers.core import Grid
@@ -57,7 +56,7 @@ def flist(items):
 
 
 class MeshView(object):
-    
+
     def __init__(self, mesh):
         self._mesh = None
         self._xyz = None
@@ -353,7 +352,7 @@ class Viewer(App):
     def mesh(self, mesh):
         self.controller.mesh = mesh
         self.controller.center_mesh()
-    
+
         self.view.glInit()
         self.view.make_buffers()
         self.view.update()
