@@ -1,18 +1,16 @@
+from __future__ import print_function
+from __future__ import absolute_import
+from __future__ import division
+
 import os
 
+import compas
+
 try:
     import rhinoscriptsyntax as rs
 
 except ImportError:
-    import sys
-    if 'ironpython' in sys.version.lower():
-        raise
-
-
-__author__     = ['Tom Van Mele', ]
-__copyright__  = 'Copyright 2014, BLOCK Research Group - ETH Zurich'
-__license__    = 'MIT License'
-__email__      = 'vanmelet@ethz.ch'
+    compas.raise_if_ironpython()
 
 
 __all__ = [
